@@ -42,7 +42,10 @@
 #include "serveroperation.h"
 #include "serverprovider.h"
 #include "set.h"
+#include "sqlexpr.h"
 #include "sqlparser.h"
+#include "sqlbuilder.h"
+#include "sqlstatement.h"
 #include "statement.h"
 #include "transactionstatus.h"
 #include "xatransaction.h"
@@ -78,6 +81,7 @@ GType gda_row_get_type(void);
 GType gda_server_operation_get_type(void);
 GType gda_server_provider_get_type(void);
 GType gda_set_get_type(void);
+GType gda_sql_builder_get_type(void);
 GType gda_sql_parser_get_type(void);
 GType gda_statement_get_type(void);
 GType gda_transaction_status_get_type(void);
@@ -91,6 +95,8 @@ GQuark gda_holder_error_quark(void);
 GQuark gda_meta_store_error_quark(void);
 GQuark gda_meta_struct_error_quark(void);
 GQuark gda_server_provider_error_quark(void);
+GQuark gda_sql_builder_error_quark(void);
+GQuark gda_sql_error_quark(void);
 GQuark gda_sql_parser_error_quark(void);
 GQuark gda_statement_error_quark(void);
 } // extern "C"
@@ -124,6 +130,7 @@ namespace Gnome { namespace Gda {  class Row_Class { public: static Glib::Object
 namespace Gnome { namespace Gda {  class ServerOperation_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gnome { namespace Gda {  class ServerProvider_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gnome { namespace Gda {  class Set_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
+namespace Gnome { namespace Gda {  class SqlBuilder_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gnome { namespace Gda {  class SqlParser_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gnome { namespace Gda {  class Statement_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gnome { namespace Gda {  class TransactionStatus_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
@@ -140,6 +147,8 @@ void wrap_init()
   Glib::Error::register_domain(gda_meta_store_error_quark(), &Gnome::Gda::MetaStoreError::throw_func);
   Glib::Error::register_domain(gda_meta_struct_error_quark(), &Gnome::Gda::MetaStructError::throw_func);
   Glib::Error::register_domain(gda_server_provider_error_quark(), &Gnome::Gda::ServerProviderError::throw_func);
+  Glib::Error::register_domain(gda_sql_builder_error_quark(), &Gnome::Gda::SqlBuilderError::throw_func);
+  Glib::Error::register_domain(gda_sql_error_quark(), &Gnome::Gda::SqlError::throw_func);
   Glib::Error::register_domain(gda_sql_parser_error_quark(), &Gnome::Gda::SqlParserError::throw_func);
   Glib::Error::register_domain(gda_statement_error_quark(), &Gnome::Gda::StatementError::throw_func);
 
@@ -170,6 +179,7 @@ void wrap_init()
   Glib::wrap_register(gda_server_operation_get_type(), &Gnome::Gda::ServerOperation_Class::wrap_new);
   Glib::wrap_register(gda_server_provider_get_type(), &Gnome::Gda::ServerProvider_Class::wrap_new);
   Glib::wrap_register(gda_set_get_type(), &Gnome::Gda::Set_Class::wrap_new);
+  Glib::wrap_register(gda_sql_builder_get_type(), &Gnome::Gda::SqlBuilder_Class::wrap_new);
   Glib::wrap_register(gda_sql_parser_get_type(), &Gnome::Gda::SqlParser_Class::wrap_new);
   Glib::wrap_register(gda_statement_get_type(), &Gnome::Gda::Statement_Class::wrap_new);
   Glib::wrap_register(gda_transaction_status_get_type(), &Gnome::Gda::TransactionStatus_Class::wrap_new);
@@ -202,6 +212,7 @@ void wrap_init()
   Gnome::Gda::ServerOperation::get_type();
   Gnome::Gda::ServerProvider::get_type();
   Gnome::Gda::Set::get_type();
+  Gnome::Gda::SqlBuilder::get_type();
   Gnome::Gda::SqlParser::get_type();
   Gnome::Gda::Statement::get_type();
   Gnome::Gda::TransactionStatus::get_type();
